@@ -24,7 +24,7 @@ import yoton
 
 import pyzo
 from pyzo.util import zon as ssdf  # zon is ssdf-light
-from pyzo.util.qt import QtCore, QtGui, QtWidgets
+from pyzo.qt import QtCore, QtGui, QtWidgets
 
 Qt = QtCore.Qt
 
