@@ -14,7 +14,7 @@ and a dialog to edit the shell configurations.
 
 import time
 import webbrowser
-from pyzo.util.qt import QtCore, QtGui, QtWidgets  # noqa
+from pyzo.qt import QtCore, QtGui, QtWidgets  # noqa
 
 import pyzo
 from pyzo import translate
@@ -619,7 +619,7 @@ class InterpreterHelper(QtWidgets.QWidget):
 
     def refresh(self):
         self._label.setText("Detecting interpreters ...")
-        QtWidgets.qApp.flush()
+        QtWidgets.qApp.sendPostedEvents()
         QtWidgets.qApp.processEvents()
         self.detect()
 
