@@ -562,7 +562,7 @@ class App_qt(App_base):
             return self._original_excepthook(type, value, traceback)
 
     def process_events(self):
-        self.app.flush()
+        self.app.sendPostedEvents()
         self.app.processEvents()
 
     def run(self, repl_callback, sleeptime=None):
@@ -575,7 +575,7 @@ class App_qt(App_base):
 
         # Enter Qt mainloop
         # self._QtGui.real_QApplication.exec_(self.app)
-        exec_ = getattr(self._QtGui.real_QApplication, "exec")
+        exec_ = getattr(self._QtGui.real_QApplication, "exec", None)
         if exec_ is None:
             exec_ = self._QtGui.real_QApplication.exec_
         try:
